tlslite.messages.ChangeCipherSpec

Package tlslite :: Module messages :: Class ChangeCipherSpec |
[show private | hide private]
[frames | no frames]

## Class ChangeCipherSpec

    Msg --+
          |
         ChangeCipherSpec

Method Summary
| `__init__(self)`
| `create(self)`
| `parse(self, p)`
| `write(self, trial)`
Inherited from Msg
| ``postWrite`(self, w, trial)`
| ``preWrite`(self, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net